@@ -1,23 +1,9 @@
 /*
+ * Copyright 2020 Han Young <hanyoung@protonmail.com>
+ * Copyright 2020 Devin Lin <espidev@gmail.com>
  * Copyright 2019 Nick Reitemeyer <nick.reitemeyer@web.de>
- *           2020 Devin Lin <espidev@gmail.com>
- *                Han Young <hanyoung@protonmail.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "alarm.h"
@@ -28,6 +14,7 @@
 #include "stopwatchtimer.h"
 #include "timer.h"
 #include "timermodel.h"
+#include "timerpresetmodel.h"
 #include "timezoneselectormodel.h"
 #include "utilmodel.h"
 #include "version.h"
@@ -44,7 +31,6 @@
 #include <QMetaObject>
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
-#include <QQmlDebuggingEnabler>
 #include <QQuickWindow>
 #include <QStringLiteral>
 
@@ -60,7 +46,6 @@ QCommandLineParser *createParser()
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
-    QQmlDebuggingEnabler enabler;
 
     KLocalizedString::setApplicationDomain("kclock");
     KAboutData aboutData("kclock",
@@ -91,6 +76,9 @@ int main(int argc, char *argv[])
     // register QML types
     qmlRegisterType<Alarm>("kclock", 1, 0, "Alarm");
     qmlRegisterType<Timer>("kclock", 1, 0, "Timer");
+    qmlRegisterSingletonType<TimerPresetModel>("kclock", 1, 0, "TimerPresetModel", [](QQmlEngine *, QJSEngine *) -> QObject * {
+        return TimerPresetModel::instance();
+    });
 
     QQmlApplicationEngine *engine = new QQmlApplicationEngine();
 
